@@ -1,7 +1,6 @@
 package Lingua::JA::Categorize::Generator;
 use strict;
 use warnings;
-use Algorithm::NaiveBayes;
 use Lingua::JA::Expand;
 use base qw( Lingua::JA::Categorize::Base );
 
@@ -20,7 +19,6 @@ sub generate {
         my @keyword = @{ $ref->{keyword} };
         for my $keyword (@keyword) {
             my $word_set = $expander->expand($keyword);
-            #$self->_expand_recursive( $word_set, $keyword );
             $brain->add_instance(
                 attributes => $word_set,
                 label      => $label,
@@ -39,35 +37,6 @@ sub generate {
     $brain->save_state($save_file) if $save_file;
 }
 
-sub _expand_recursive {
-    my $self     = shift;
-    my $word_set = shift;
-    my $keyword  = shift;
-    my @array;
-    for ( sort { $word_set->{$b} <=> $word_set->{$a} } keys %$word_set ) {
-        push @array, $_;
-    }
-    for ( 1 .. 10 ) {
-        my $n           = $_ - 1;
-        my $sub_keyword = $array[$n];
-        my $exp         = Lingua::JA::Expand->new;
-        my $new_keyword = $keyword . ' ' . $sub_keyword;
-        my $sub_result  = $exp->expand($new_keyword);
-        $self->_merge_hash( $word_set, $sub_result );
-    }
-    use Data::Dumper;
-    print Dumper $word_set;
-}
-
-sub _merge_hash {
-    my $self       = shift;
-    my $hash_ref_a = shift;
-    my $hash_ref_b = shift;
-    while ( my ( $key_b, $value_b ) = each %$hash_ref_b ) {
-        $hash_ref_a->{$key_b} += $value_b;
-    }
-}
-
 1;
 __END__
 
